@@ -15,16 +15,14 @@ class ImageFileExecutionOptions(Plugin):
     COMPATIBLE_HIVE = SOFTWARE_HIVE_TYPE
 
     def run(self):
-        entries = []
         image_file_execution_options = self.registry_hive.get_key(IMAGE_FILE_EXECUTION_OPTIONS)
         if image_file_execution_options.subkey_count:
             for subkey in image_file_execution_options.iter_subkeys():
-                values = {x['name']: x['value'] for x in
+                values = {x.name: x.value for x in
                           subkey.iter_values(as_json=self.as_json)} if subkey.values_count else {}
-                entries.append({
+                self.entries.append({
                     'name': subkey.name,
                     'timestamp': convert_wintime(subkey.header.last_modified, as_json=self.as_json),
                     **values
 
                 })
-        return entries
